# Bind Operator

A Juju charm deploying Bind, configurable to use a git repository for its configuration files.

## Overview

BIND 9 has evolved to be a very flexible, full-featured DNS system. Whatever
your application is, BIND 9 probably has the required features. As the first,
oldest, and most commonly deployed solution, there are more network engineers
who are already familiar with BIND 9 than with any other system.

## Usage

For details on using Kubernetes with Juju [see here](https://juju.is/docs/kubernetes), and for
details on using Juju with MicroK8s for easy local testing [see here](https://juju.is/docs/microk8s-cloud).

To deploy this charm in a juju k8s model:
```
juju deploy cs:~bind-charmers/bind
```
The charm will deploy bind with its stock Ubuntu package configuration, which
will forward all queries to root name servers.

DNSSEC is also enabled by default.

Custom config can be deployed by setting the `custom_config_repo` option to
point to a Git repository containing a valid set of configuration files with
which to populate the `/etc/bind/` directory within the pod(s).

Since bind won't allow recursion from external clients by default, to allow
easy testing, you can use [a repo with a copy of the stock config, modified to allow recursion from all RFC1918 networks](https://code.launchpad.net/~barryprice/junk/+git/etc-bind-stock-config-with-all-rfc1918-nets-allowed):
```
juju config bind custom_config_repo=https://git.launchpad.net/~barryprice/junk/+git/etc-bind-stock-config-with-all-rfc1918-nets-allowed
```
Once the application is ready, you should be able to query the App's IP address
(not the Unit addresses) directly from your local machine:

```
$ juju status

Model      Controller       Cloud/Region     Version  SLA          Timestamp
bind-test  myk8s-localhost  myk8s/localhost  2.8.6    unsupported  16:44:30+07:00

App   Version    Status  Scale  Charm  Store       Rev  OS          Address         Notes
bind  bind:edge  active      1  bind   jujucharms    2  kubernetes  10.152.183.246

Unit     Workload  Agent  Address     Ports          Message
bind/0*  active    idle   10.1.25.35  53/TCP,53/UDP  Pod configured

$ dig +short example.com @10.152.183.246
93.184.216.34
$
```

## Known Issues

This charm is unable to provide an ingress to route TCP and UDP traffic to the
pods due to [LP#1889703](https://bugs.launchpad.net/juju/+bug/1889703). This is
also being tracked as [a bug against the charm itself](https://bugs.launchpad.net/charm-k8s-bind/+bug/1889746).
